/****************************************************************************
    Qt-BSch3V schematic capture
    Copyright (C) 2002-2005 H.Okada

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*****************************************************************************/

#include "sheetsize.h"

#include <qlabel.h>
#include <qlineedit.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qvariant.h>
#include <qtooltip.h>
#include <q3whatsthis.h>
//Added by qt3to4:
#include <QHBoxLayout>
#include <QGridLayout>

/* 
 *  Constructs a sheetsizeBase which is a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f' 
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
sheetsizeBase::sheetsizeBase( QWidget* parent,  const char* name, bool modal, Qt::WFlags fl )
    : QDialog( parent, name, modal, fl )
{
    if ( !name )
	setName( "sheetsizeBase" );
    resize( 207, 103 ); 
    setProperty( "windowTitle", tr( "Qt-BSch Sheet size" ) );
//    setProperty( "caption", tr( "Qt-BSch Sheet size" ) );
    setProperty( "sizeGripEnabled", QVariant( FALSE, 0 ) );
    sheetsizeBaseLayout = new QGridLayout( this ); 
    sheetsizeBaseLayout->setSpacing( 6 );
    sheetsizeBaseLayout->setMargin( 11 );

    TextLabel1_2_2 = new QLabel( this, "TextLabel1_2_2" );
    TextLabel1_2_2->setProperty( "text", tr( "Height(400~2000)" ) );

    sheetsizeBaseLayout->addWidget( TextLabel1_2_2, 1, 0 );

    TextLabel1_2 = new QLabel( this, "TextLabel1_2" );
    TextLabel1_2->setProperty( "text", tr( "Width(500~3000)" ) );

    sheetsizeBaseLayout->addWidget( TextLabel1_2, 0, 0 );

    EditWidth = new QLineEdit( this, "EditWidth" );
    EditWidth->setProperty( "maxLength", 4 );

    sheetsizeBaseLayout->addWidget( EditWidth, 0, 1 );

    EditHeight = new QLineEdit( this, "EditHeight" );
    EditHeight->setProperty( "maxLength", 4 );

    sheetsizeBaseLayout->addWidget( EditHeight, 1, 1 );

    Layout4 = new QHBoxLayout; 
    Layout4->setSpacing( 6 );
    Layout4->setMargin( 0 );
    QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    Layout4->addItem( spacer );

    buttonOk = new QPushButton( this, "buttonOk" );
    //buttonOk->setProperty( "caption", tr( "" ) );
    buttonOk->setProperty( "text", tr( "&OK" ) );
    buttonOk->setProperty( "autoDefault", QVariant( TRUE, 0 ) );
    buttonOk->setProperty( "default", QVariant( TRUE, 0 ) );
    Layout4->addWidget( buttonOk );

    buttonCancel = new QPushButton( this, "buttonCancel" );
    buttonCancel->setProperty( "text", tr( "&Cancel" ) );
    buttonCancel->setProperty( "autoDefault", QVariant( TRUE, 0 ) );
    Layout4->addWidget( buttonCancel );

    sheetsizeBaseLayout->addMultiCellLayout( Layout4, 2, 2, 0, 1 );

    // signals and slots connections
    connect( buttonOk, SIGNAL( clicked() ), this, SLOT( accept() ) );
    connect( buttonCancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
}

/*  
 *  Destroys the object and frees any allocated resources
 */
sheetsizeBase::~sheetsizeBase()
{
    // no need to delete child widgets, Qt does it all for us
}

