/****************************************************************************
    Qt-BSch3V schematic capture
    Copyright (C) 2002-2005 H.Okada

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*****************************************************************************/

#include <qlineedit.h>
#include <qmessagebox.h>
#include "sheetsizeimpl.h"

/* 
 *  Constructs a sheetsize which is a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f' 
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
sheetsize::sheetsize( QWidget* parent,  const char* name, bool modal, Qt::WFlags fl )
    : sheetsizeBase( parent, name, modal, fl )
{
	m_width		=1500;
	m_height	=1000;
}

/*  
 *  Destroys the object and frees any allocated resources
 */
sheetsize::~sheetsize()
{
    // no need to delete child widgets, Qt does it all for us
}

int sheetsize::exec()
{
	QString str;
	str.sprintf("%d",m_width);
	EditWidth->setText(str);
	str.sprintf("%d",m_height);
	EditHeight->setText(str);
	EditWidth->setFocus();
	return sheetsizeBase::exec();
}

void sheetsize::setWidth(int n)
{
	if(n>=500 && n<=3000){
		m_width = n;
	}
}
void sheetsize::setHeight(int n)
{
	if(n>=400 && n<=2000){
		m_height = n;
	}
}

void sheetsize::accept()
{
	int n = EditWidth->text().toInt();
	if(n<500 || n>3000){
		QMessageBox::critical( this, "Set Sheet size",
							"Width is out of range.",
							"OK",QString::null,QString::null,0,0);

		return;
	}else{
		m_width = n;
	}
	n = EditHeight->text().toInt();
	if(n<400 || n>2000){
		QMessageBox::critical( this, "Set Sheet size",
							"Height is out of range.",
							"OK",QString::null,QString::null,0,0);
		return;
	}else{
		m_height = n;
	}
	sheetsizeBase::accept();
}
